# frozen_string_literal: true

#
# Cookbook Name:: samhain
# Library:: resource/samhain
#
# Copyright:: 2015, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/resource'

class Chef
  class Resource
    # A parent Chef resource for all the Samhain components.
    class Samhain < Resource
      provides :samhain

      default_action :create

      #
      # Set a default name since it's never used.
      #
      property :name, String, default: 'default'

      #
      # Property for an input config hash.
      #
      property :config, Hash, default: {}

      #
      # Property to allow an override of the default package source path/URL.
      #
      property :source, String

      #
      # Install, configure, and enable+start Samhain.
      #
      action :create do
        samhain_app(new_resource.name) do
          source new_resource.source unless new_resource.source.nil?
        end
        samhain_config(new_resource.name) do
          config new_resource.config unless new_resource.config.nil?
          notifies :reload, "samhain_service[#{new_resource.name}]"
        end
        samhain_service(new_resource.name)
      end

      #
      # Disable+stop Samhain, remove its configuration, and uninstall the app.
      #
      action :remove do
        samhain_service(new_resource.name) { action %i[stop disable remove] }
        samhain_config(new_resource.name) { action :remove }
        samhain_app(new_resource.name) { action :remove }
      end
    end
  end
end
