# frozen_string_literal: true

#
# Cookbook Name:: samhain
# Library:: resource/samhain_app_debian
#
# Copyright:: 2015, Tyler Technologies
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require_relative 'samhain_app'

class Chef
  class Resource
    # A Samhain app resource for Debian platforms.
    class SamhainAppDebian < SamhainApp
      provides :samhain_app, platform_family: 'debian'

      #
      # Ensure the APT cache is up to date and install the Samhain package.
      #
      action :install do
        apt_update 'default'
        super()
      end

      #
      # Use the :purge action to remove Samhain instead of :remove.
      #
      action :remove do
        package('samhain') { action :purge }
      end
    end
  end
end
